@@ -209,6 +209,7 @@ wvar.imu = function(x, decomp="modwt", filter = "haar", nlevels = NULL, alpha =
 #' @rdname wvar
 #' @export
 #' @importFrom methods is
+#' @importFrom simts WN
 wvar.default = function(x, decomp = "modwt", filter = "haar", nlevels = NULL, alpha = 0.05, robust = FALSE, eff = 0.6, freq = 1, from.unit = NULL, to.unit = NULL, ...){
   if(is.null(x)){
     stop("`x` must contain a value")
@@ -269,19 +270,31 @@ wvar.default = function(x, decomp = "modwt", filter = "haar", nlevels = NULL, al
   }else{
     unit = from.unit}
   
-  create_wvar(obj, decomp, filter, robust, eff, alpha, scales, unit)
+  # Additional internal useful values
+  mean_diff = mean(diff(x))
+  N = length(x)
+  ranged = (max(x) - min(x))/N
+  J = nlevels
+  
+  create_wvar(obj, decomp, filter, robust, eff, alpha, scales, unit,
+              mean_diff, N, ranged, J)
 }
 
 #' @title Create a \code{wvar} object
 #' @description Structures elements into a \code{wvar} object
-#' @param obj    A \code{matrix} with dimensions N x 3 that contains Wavelet Variance, Lower CI, and Upper CI.
-#' @param decomp A \code{string} that indicates whether to use a "dwt" or "modwt" decomposition.
-#' @param filter A \code{string} that specifies the type of wavelet filter used in the decomposition.
-#' @param robust A \code{boolean} that triggers the use of the robust estimate.
-#' @param eff    A \code{double} that indicates the efficiency as it relates to an MLE.
-#' @param alpha  A \code{double} that specifies the significance level which in turn specifies the \eqn{1-\alpha} confidence level.
-#' @param scales A \code{vec} that contains the amount of decomposition performed at each level.
-#' @param unit   A \code{string} that indicates the unit expression of the frequency.
+#' @param obj         A \code{matrix} with dimensions N x 3 that contains Wavelet Variance, Lower CI, and Upper CI.
+#' @param decomp      A \code{string} that indicates whether to use a "dwt" or "modwt" decomposition.
+#' @param filter      A \code{string} that specifies the type of wavelet filter used in the decomposition.
+#' @param robust      A \code{boolean} that triggers the use of the robust estimate.
+#' @param eff         A \code{double} that indicates the efficiency as it relates to an MLE.
+#' @param alpha       A \code{double} that specifies the significance level which in turn specifies the \eqn{1-\alpha} confidence level.
+#' @param scales      A \code{vec} that contains the amount of decomposition performed at each level.
+#' @param unit        A \code{string} that indicates the unit expression of the frequency.
+#' @param mean_diff   A \code{double} that specified the empirical mean of the first difference.
+#' @param N           A \code{integer} that specified the empirical length of the time series.
+#' @param ranged      A \code{double} that specified the scaled range of the data, i.e. (max(x) - min(x))/length(x).
+#' @param J           A \code{integer} that specified the number of scales.
+#' 
 #' @return A \code{list} with the structure:
 #' \itemize{
 #'   \item "variance": Wavelet variance
@@ -291,9 +304,13 @@ wvar.default = function(x, decomp = "modwt", filter = "haar", nlevels = NULL, al
 #'   \item "eff": Efficiency level for robust calculation
 #'   \item "alpha": p value used for CI
 #'   \item "unit": String representation of the unit
+#'   \item "mean_diff": Empirical mean of the first difference
+#'   \item "N": Length of the time series
+#'   \item "ranged": Scaled range of the data, i.e. (max(x) - min(x))/length(x)
+#'   \item "J": Number of scales
 #' }
 #' @keywords internal
-create_wvar = function(obj, decomp, filter, robust, eff, alpha, scales, unit){
+create_wvar = function(obj, decomp, filter, robust, eff, alpha, scales, unit, mean_diff, N, ranged, J){
   structure(list(variance = obj[,1],
                  ci_low = obj[,2], 
                  ci_high = obj[,3], 
@@ -303,6 +320,10 @@ create_wvar = function(obj, decomp, filter, robust, eff, alpha, scales, unit){
                  scales = scales,
                  decomp = decomp,
                  unit = unit,
+                 mean_diff = mean_diff,
+                 N = N,
+                 ranged = ranged,
+                 J = J,
                  filter = filter), class = "wvar")
 }
 
@@ -975,7 +996,7 @@ compare_wvar_split = function(graph_details){
         
 #        if (graph_details$add_legend){
 #          if (i == j){
-#            legend(graph_details$legend_position, graph_details$names, bty = "n",
+#            legend(graph_details$legend_position, legend = graph_details$names, bty = "n",
 #                   lwd = 1, pt.cex = graph_details$point_cex, pch = graph_details$point_pch,
 #                   col = graph_details$col_wv, cex=0.7)
 #          }
@@ -1121,7 +1142,7 @@ compare_wvar_no_split = function(graph_details){
   }
   
   if (graph_details$add_legend){
-    legend(graph_details$legend_position, graph_details$names, bty = "n",
+    legend(graph_details$legend_position, legend = graph_details$names, bty = "n",
            lwd = 1, pt.cex = graph_details$point_cex, pch = graph_details$point_pch,
            col = graph_details$col_wv)
   }
@@ -1151,6 +1172,8 @@ compare_wvar_no_split = function(graph_details){
 #' @param point_pch       A \code{double} that specifies the symbol type to be plotted.
 #' @param names           A \code{string} that specifies the name of the WVAR objects. 
 #' @param cex_labels      A \code{double} that specifies the magnification of the labels (x and y).
+#' @param x_range         A \code{vector} that specifies the range of values on the x axis (default NULL).
+#' @param y_range         A \code{vector} that specifies the range of values on the y axis (default NULL).
 #' @author Stephane Guerrier and Justin Lee
 #' @export
 #' @examples
@@ -1170,7 +1193,7 @@ compare_wvar_no_split = function(graph_details){
 compare_wvar = function(... , split = FALSE, add_legend = TRUE, units = NULL, xlab = NULL, 
                         ylab = NULL, main = NULL, col_wv = NULL, col_ci = NULL, nb_ticks_x = NULL, 
                         nb_ticks_y = NULL, legend_position = NULL, ci_wv = NULL, point_cex = NULL, 
-                        point_pch = NULL, names = NULL, cex_labels = 0.8){
+                        point_pch = NULL, names = NULL, cex_labels = 0.8, x_range = NULL, y_range = NULL){
   
   obj_list = list(...)
   obj_name = as.character(substitute(...()))
@@ -1242,7 +1265,7 @@ compare_wvar = function(... , split = FALSE, add_legend = TRUE, units = NULL, xl
     }
     
     # X and Y Limits
-    x_range = y_range = rep(NULL, 2)
+    #x_range = y_range = rep(NULL, 2)
     for (i in 1:obj_len){
       x_range = range(c(x_range, obj_list[[i]]$scales))
       y_range = range(c(y_range, obj_list[[i]]$ci_low, obj_list[[i]]$ci_high))
